==> cristalise-kernel-3.2-sources.jar: org/cristalise/kernel/lifecycle/instance/stateMachine/TransitionOutcome.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.lifecycle.instance.stateMachine;


public class TransitionOutcome extends TransitionResource {
	
	// schema properties
	String schemaName, schemaVersion; // Name & version of the schema of the data required for this transition. 
	boolean required = true; // If true, then the data must be supplied to perform the transition, otherwise it is optional
	
    public TransitionOutcome() {
    }

    public TransitionOutcome(String schema, String version) {
        this.schemaName = schema;
        this.schemaVersion = version;
    }

	public String getSchemaName() {
		return schemaName;
	}

	public void setSchemaName(String schemaName) {
		this.schemaName = schemaName;
	}

	public String getSchemaVersion() {
		return schemaVersion;
	}

	public void setSchemaVersion(String schemaVersion) {
		this.schemaVersion = schemaVersion;
	}

	public boolean isRequired() {
		return required;
	}

	public void setRequired(boolean required) {
		this.required = required;
	}

}

==> cristalise-kernel-3.3-sources.jar: org/cristalise/kernel/lifecycle/instance/stateMachine/TransitionOutcome.java <==
/**
 * This file is part of the CRISTAL-iSE kernel.
 * Copyright (c) 2001-2015 The CRISTAL Consortium. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published
 * by the Free Software Foundation; either version 3 of the License, or (at
 * your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; with out even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 * License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * http://www.fsf.org/licensing/licenses/lgpl.html
 */
package org.cristalise.kernel.lifecycle.instance.stateMachine;

import lombok.Getter;
import lombok.Setter;

@Getter @Setter
public class TransitionOutcome {

    // schema properties
    /**
     * Name & version of the schema of the data required for this transition
     */
    String  schemaName, schemaVersion;
    /**
     * If true, then the data must be supplied to perform the transition,
     * otherwise it is optional
     */
    boolean required = true;

    public TransitionOutcome() {}

    public TransitionOutcome(String schema, String version) {
        this.schemaName = schema;
        this.schemaVersion = version;
    }
}
